@@ -1,11 +1,19 @@
 # flake8: noqa
-from importlib_metadata import version  # type: ignore
+try:
+    # python 3.7 and earlier
+    from importlib_metadata import version  # type: ignore
+except ImportError:
+    # python 3.8 and later
+    from importlib.metadata import version  # type: ignore
+
+from miio.airconditioner_miot import AirConditionerMiot
 from miio.airconditioningcompanion import (
     AirConditioningCompanion,
     AirConditioningCompanionV3,
 )
+from miio.airconditioningcompanionMCN import AirConditioningCompanionMcn02
 from miio.airdehumidifier import AirDehumidifier
-from miio.airfresh import AirFresh
+from miio.airfresh import AirFresh, AirFreshVA4
 from miio.airfresh_t2017 import AirFreshT2017
 from miio.airhumidifier import AirHumidifier, AirHumidifierCA1, AirHumidifierCB1
 from miio.airhumidifier_jsq import AirHumidifierJsq
@@ -20,9 +28,11 @@ from miio.chuangmi_camera import ChuangmiCamera
 from miio.chuangmi_ir import ChuangmiIr
 from miio.chuangmi_plug import ChuangmiPlug, Plug, PlugV1, PlugV3
 from miio.cooker import Cooker
+from miio.curtain_youpin import CurtainMiot
 from miio.device import Device
 from miio.exceptions import DeviceError, DeviceException
 from miio.fan import Fan, FanP5, FanSA1, FanV2, FanZA1, FanZA4
+from miio.fan_miot import FanMiot, FanP9, FanP10, FanP11
 from miio.gateway import Gateway
 from miio.heater import Heater
 from miio.philips_bulb import PhilipsBulb, PhilipsWhiteBulb
@@ -34,6 +44,7 @@ from miio.protocol import Message, Utils
 from miio.pwzn_relay import PwznRelay
 from miio.toiletlid import Toiletlid
 from miio.vacuum import Vacuum, VacuumException
+from miio.vacuum_tui import VacuumTUI
 from miio.vacuumcontainers import (
     CleaningDetails,
     CleaningSummary,
@@ -44,6 +55,7 @@ from miio.vacuumcontainers import (
 )
 from miio.viomivacuum import ViomiVacuum
 from miio.waterpurifier import WaterPurifier
+from miio.waterpurifier_yunmi import WaterPurifierYunmi
 from miio.wifirepeater import WifiRepeater
 from miio.wifispeaker import WifiSpeaker
 from miio.yeelight import Yeelight
