@@ -184,9 +184,6 @@ class AirDehumidifierStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class AirDehumidifier(Device):
     """Implementation of Xiaomi Mi Air Dehumidifier."""
@@ -253,7 +250,7 @@ class AirDehumidifier(Device):
         return self.send("set_power", ["off"])
 
     @command(
-        click.argument("mode", type=EnumType(OperationMode, False)),
+        click.argument("mode", type=EnumType(OperationMode)),
         default_output=format_output("Setting mode to '{mode.value}'"),
     )
     def set_mode(self, mode: OperationMode):
@@ -268,7 +265,7 @@ class AirDehumidifier(Device):
             raise
 
     @command(
-        click.argument("fan_speed", type=EnumType(FanSpeed, False)),
+        click.argument("fan_speed", type=EnumType(FanSpeed)),
         default_output=format_output("Setting fan level to {fan_level}"),
     )
     def set_fan_speed(self, fan_speed: FanSpeed):
