@@ -49,7 +49,6 @@ class OperationMode(enum.Enum):
 
 
 class PtcLevel(enum.Enum):
-    Off = "off"
     Low = "low"
     Medium = "medium"
     High = "high"
@@ -230,9 +229,6 @@ class AirFreshStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class AirFreshT2017(Device):
     """Main class representing the air fresh t2017."""
@@ -287,15 +283,15 @@ class AirFreshT2017(Device):
     @command(default_output=format_output("Powering on"))
     def on(self):
         """Power on."""
-        return self.send("set_power", ["on"])
+        return self.send("set_power", [True])
 
     @command(default_output=format_output("Powering off"))
     def off(self):
         """Power off."""
-        return self.send("set_power", ["off"])
+        return self.send("set_power", [False])
 
     @command(
-        click.argument("mode", type=EnumType(OperationMode, False)),
+        click.argument("mode", type=EnumType(OperationMode)),
         default_output=format_output("Setting mode to '{mode.value}'"),
     )
     def set_mode(self, mode: OperationMode):
@@ -310,13 +306,10 @@ class AirFreshT2017(Device):
     )
     def set_display(self, display: bool):
         """Turn led on/off."""
-        if display:
-            return self.send("set_display", ["on"])
-        else:
-            return self.send("set_display", ["off"])
+        return self.send("set_display", [display])
 
     @command(
-        click.argument("orientation", type=EnumType(DisplayOrientation, False)),
+        click.argument("orientation", type=EnumType(DisplayOrientation)),
         default_output=format_output("Setting orientation to '{orientation.value}'"),
     )
     def set_display_orientation(self, orientation: DisplayOrientation):
@@ -324,7 +317,17 @@ class AirFreshT2017(Device):
         return self.send("set_screen_direction", [orientation.value])
 
     @command(
-        click.argument("level", type=EnumType(PtcLevel, False)),
+        click.argument("ptc", type=bool),
+        default_output=format_output(
+            lambda ptc: "Turning on ptc" if ptc else "Turning off ptc"
+        ),
+    )
+    def set_ptc(self, ptc: bool):
+        """Turn ptc on/off."""
+        return self.send("set_ptc_on", [ptc])
+
+    @command(
+        click.argument("level", type=EnumType(PtcLevel)),
         default_output=format_output("Setting ptc level to '{level.value}'"),
     )
     def set_ptc_level(self, level: PtcLevel):
@@ -339,10 +342,7 @@ class AirFreshT2017(Device):
     )
     def set_buzzer(self, buzzer: bool):
         """Set sound on/off."""
-        if buzzer:
-            return self.send("set_sound", ["on"])
-        else:
-            return self.send("set_sound", ["off"])
+        return self.send("set_sound", [buzzer])
 
     @command(
         click.argument("lock", type=bool),
@@ -352,10 +352,7 @@ class AirFreshT2017(Device):
     )
     def set_child_lock(self, lock: bool):
         """Set child lock on/off."""
-        if lock:
-            return self.send("set_child_lock", ["on"])
-        else:
-            return self.send("set_child_lock", ["off"])
+        return self.send("set_child_lock", [lock])
 
     @command(default_output=format_output("Resetting upper filter"))
     def reset_upper_filter(self):
