@@ -248,9 +248,6 @@ class AirHumidifierStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class AirHumidifier(Device):
     """Implementation of Xiaomi Mi Air Humidifier."""
@@ -326,7 +323,7 @@ class AirHumidifier(Device):
         return self.send("set_power", ["off"])
 
     @command(
-        click.argument("mode", type=EnumType(OperationMode, False)),
+        click.argument("mode", type=EnumType(OperationMode)),
         default_output=format_output("Setting mode to '{mode.value}'"),
     )
     def set_mode(self, mode: OperationMode):
@@ -341,7 +338,7 @@ class AirHumidifier(Device):
             raise
 
     @command(
-        click.argument("brightness", type=EnumType(LedBrightness, False)),
+        click.argument("brightness", type=EnumType(LedBrightness)),
         default_output=format_output("Setting LED brightness to {brightness}"),
     )
     def set_led_brightness(self, brightness: LedBrightness):
