@@ -151,9 +151,6 @@ class AirHumidifierStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class AirHumidifierJsq(Device):
     """
@@ -229,7 +226,7 @@ class AirHumidifierJsq(Device):
         return self.send("set_start", [0])
 
     @command(
-        click.argument("mode", type=EnumType(OperationMode, False)),
+        click.argument("mode", type=EnumType(OperationMode)),
         default_output=format_output("Setting mode to '{mode.value}'"),
     )
     def set_mode(self, mode: OperationMode):
@@ -243,7 +240,7 @@ class AirHumidifierJsq(Device):
         return self.send("set_mode", [value])
 
     @command(
-        click.argument("brightness", type=EnumType(LedBrightness, False)),
+        click.argument("brightness", type=EnumType(LedBrightness)),
         default_output=format_output("Setting LED brightness to {brightness}"),
     )
     def set_led_brightness(self, brightness: LedBrightness):
