@@ -1,7 +1,7 @@
 import enum
 import logging
 from collections import defaultdict
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 
 import click
 
@@ -12,19 +12,23 @@ from .exceptions import DeviceException
 _LOGGER = logging.getLogger(__name__)
 
 MODEL_HUMIDIFIER_MJJSQ = "deerma.humidifier.mjjsq"
+MODEL_HUMIDIFIER_JSQ1 = "deerma.humidifier.jsq1"
+
+MODEL_HUMIDIFIER_JSQ_COMMON = [
+    "OnOff_State",
+    "TemperatureValue",
+    "Humidity_Value",
+    "HumiSet_Value",
+    "Humidifier_Gear",
+    "Led_State",
+    "TipSound_State",
+    "waterstatus",
+    "watertankstatus",
+]
 
 AVAILABLE_PROPERTIES = {
-    MODEL_HUMIDIFIER_MJJSQ: [
-        "OnOff_State",
-        "TemperatureValue",
-        "Humidity_Value",
-        "HumiSet_Value",
-        "Humidifier_Gear",
-        "Led_State",
-        "TipSound_State",
-        "waterstatus",
-        "watertankstatus",
-    ]
+    MODEL_HUMIDIFIER_MJJSQ: MODEL_HUMIDIFIER_JSQ_COMMON,
+    MODEL_HUMIDIFIER_JSQ1: MODEL_HUMIDIFIER_JSQ_COMMON + ["wet_and_protect"],
 }
 
 
@@ -103,6 +107,14 @@ class AirHumidifierStatus:
         """True if the water tank is detached."""
         return self.data["watertankstatus"] == 0
 
+    @property
+    def wet_protection(self) -> Optional[bool]:
+        """True if wet protection is enabled."""
+        if self.data["wet_and_protect"] is not None:
+            return self.data["wet_and_protect"] == 1
+
+        return None
+
     def __repr__(self) -> str:
         s = (
             "<AirHumidiferStatus power=%s, "
@@ -113,7 +125,8 @@ class AirHumidifierStatus:
             "buzzer=%s, "
             "target_humidity=%s%%, "
             "no_water=%s, "
-            "water_tank_detached=%s>"
+            "water_tank_detached=%s,"
+            "wet_protection=%s>"
             % (
                 self.power,
                 self.mode,
@@ -124,13 +137,11 @@ class AirHumidifierStatus:
                 self.target_humidity,
                 self.no_water,
                 self.water_tank_detached,
+                self.wet_protection,
             )
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class AirHumidifierMjjsq(Device):
     def __init__(
@@ -160,7 +171,8 @@ class AirHumidifierMjjsq(Device):
             "Buzzer: {result.buzzer}\n"
             "Target humidity: {result.target_humidity} %\n"
             "No water: {result.no_water}\n"
-            "Water tank detached: {result.water_tank_detached}\n",
+            "Water tank detached: {result.water_tank_detached}\n"
+            "Wet protection: {result.wet_protection}\n",
         )
     )
     def status(self) -> AirHumidifierStatus:
@@ -182,7 +194,7 @@ class AirHumidifierMjjsq(Device):
         return self.send("Set_OnOff", [0])
 
     @command(
-        click.argument("mode", type=EnumType(OperationMode, False)),
+        click.argument("mode", type=EnumType(OperationMode)),
         default_output=format_output("Setting mode to '{mode.value}'"),
     )
     def set_mode(self, mode: OperationMode):
@@ -219,3 +231,15 @@ class AirHumidifierMjjsq(Device):
             raise AirHumidifierException("Invalid target humidity: %s" % humidity)
 
         return self.send("Set_HumiValue", [humidity])
+
+    @command(
+        click.argument("protection", type=bool),
+        default_output=format_output(
+            lambda protection: "Turning on wet protection"
+            if protection
+            else "Turning off wet protection"
+        ),
+    )
+    def set_wet_protection(self, protection: bool):
+        """Turn wet protection on/off."""
+        return self.send("Set_wet_and_protect", [int(protection)])
