@@ -334,9 +334,6 @@ class AirPurifierStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class AirPurifier(Device):
     """Main class representing the air purifier."""
@@ -409,23 +406,7 @@ class AirPurifier(Device):
             "button_pressed",
         ]
 
-        # A single request is limited to 16 properties. Therefore the
-        # properties are divided into multiple requests
-        _props = properties.copy()
-        values = []
-        while _props:
-            values.extend(self.send("get_prop", _props[:15]))
-            _props[:] = _props[15:]
-
-        properties_count = len(properties)
-        values_count = len(values)
-        if properties_count != values_count:
-            _LOGGER.debug(
-                "Count (%s) of requested properties does not match the "
-                "count (%s) of received values.",
-                properties_count,
-                values_count,
-            )
+        values = self.get_properties(properties, max_properties=15)
 
         return AirPurifierStatus(defaultdict(lambda: None, zip(properties, values)))
 
@@ -440,7 +421,7 @@ class AirPurifier(Device):
         return self.send("set_power", ["off"])
 
     @command(
-        click.argument("mode", type=EnumType(OperationMode, False)),
+        click.argument("mode", type=EnumType(OperationMode)),
         default_output=format_output("Setting mode to '{mode.value}'"),
     )
     def set_mode(self, mode: OperationMode):
@@ -463,7 +444,7 @@ class AirPurifier(Device):
         return self.send("set_level_favorite", [level])  # 0 ... 17
 
     @command(
-        click.argument("brightness", type=EnumType(LedBrightness, False)),
+        click.argument("brightness", type=EnumType(LedBrightness)),
         default_output=format_output("Setting LED brightness to {brightness}"),
     )
     def set_led_brightness(self, brightness: LedBrightness):
