@@ -248,9 +248,6 @@ class AirPurifierMiotStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class AirPurifierMiot(MiotDevice):
     """Main class representing the air purifier which uses MIoT protocol."""
@@ -348,7 +345,7 @@ class AirPurifierMiot(MiotDevice):
         return self.set_property("buzzer_volume", volume)
 
     @command(
-        click.argument("mode", type=EnumType(OperationMode, False)),
+        click.argument("mode", type=EnumType(OperationMode)),
         default_output=format_output("Setting mode to '{mode.value}'"),
     )
     def set_mode(self, mode: OperationMode):
@@ -361,7 +358,7 @@ class AirPurifierMiot(MiotDevice):
     )
     def set_favorite_level(self, level: int):
         """Set the favorite level used when the mode is `favorite`,
-         should be  between 0 and 14.
+        should be  between 0 and 14.
         """
         if level < 0 or level > 14:
             raise AirPurifierMiotException("Invalid favorite level: %s" % level)
@@ -369,7 +366,7 @@ class AirPurifierMiot(MiotDevice):
         return self.set_property("favorite_level", level)
 
     @command(
-        click.argument("brightness", type=EnumType(LedBrightness, False)),
+        click.argument("brightness", type=EnumType(LedBrightness)),
         default_output=format_output("Setting LED brightness to {brightness}"),
     )
     def set_led_brightness(self, brightness: LedBrightness):
