@@ -87,9 +87,6 @@ class CeilStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class Ceil(Device):
     """Main class representing Xiaomi Philips LED Ceiling Lamp."""
