@@ -55,9 +55,6 @@ class DeviceInfo:
             self.data["token"],
         )
 
-    def __json__(self):
-        return self.data
-
     @property
     def network_interface(self):
         """Information about network configuration."""
@@ -169,9 +166,7 @@ class Device(metaclass=DeviceGroupMeta):
             "",
             "Model: {result.model}\n"
             "Hardware version: {result.hardware_version}\n"
-            "Firmware version: {result.firmware_version}\n"
-            "Network: {result.network_interface}\n"
-            "AP: {result.accesspoint}\n",
+            "Firmware version: {result.firmware_version}\n",
         )
     )
     def info(self) -> DeviceInfo:
@@ -185,6 +180,11 @@ class Device(metaclass=DeviceGroupMeta):
                 "Unable to request miIO.info from the device"
             ) from ex
 
+    @property
+    def raw_id(self):
+        """Return the last used protocol sequence id."""
+        return self._protocol.raw_id
+
     def update(self, url: str, md5: str):
         """Start an OTA update."""
         payload = {
