@@ -8,7 +8,9 @@ from typing import Callable, Dict, Optional, Union  # noqa: F401
 import zeroconf
 
 from . import (
+    AirConditionerMiot,
     AirConditioningCompanion,
+    AirConditioningCompanionMcn02,
     AirFresh,
     AirFreshT2017,
     AirHumidifier,
@@ -25,6 +27,7 @@ from . import (
     Cooker,
     Device,
     Fan,
+    FanMiot,
     Heater,
     PhilipsBulb,
     PhilipsEyecare,
@@ -36,6 +39,7 @@ from . import (
     Vacuum,
     ViomiVacuum,
     WaterPurifier,
+    WaterPurifierYunmi,
     WifiRepeater,
     WifiSpeaker,
     Yeelight,
@@ -45,12 +49,14 @@ from .airconditioningcompanion import (
     MODEL_ACPARTNER_V2,
     MODEL_ACPARTNER_V3,
 )
+from .airconditioningcompanionMCN import MODEL_ACPARTNER_MCN02
+from .airfresh import MODEL_AIRFRESH_VA2, MODEL_AIRFRESH_VA4
 from .airhumidifier import (
     MODEL_HUMIDIFIER_CA1,
     MODEL_HUMIDIFIER_CB1,
     MODEL_HUMIDIFIER_V1,
 )
-from .airhumidifier_mjjsq import MODEL_HUMIDIFIER_MJJSQ
+from .airhumidifier_mjjsq import MODEL_HUMIDIFIER_JSQ1, MODEL_HUMIDIFIER_MJJSQ
 from .airqualitymonitor import (
     MODEL_AIRQUALITYMONITOR_B1,
     MODEL_AIRQUALITYMONITOR_S1,
@@ -75,6 +81,7 @@ from .fan import (
     MODEL_FAN_ZA3,
     MODEL_FAN_ZA4,
 )
+from .fan_miot import MODEL_FAN_P9, MODEL_FAN_P10, MODEL_FAN_P11
 from .heater import MODEL_HEATER_MA1, MODEL_HEATER_ZA1
 from .powerstrip import MODEL_POWER_STRIP_V1, MODEL_POWER_STRIP_V2
 from .toiletlid import MODEL_TOILETLID_V1
@@ -97,6 +104,10 @@ DEVICE_MAP = {
     "qmi-powerstrip-v1": partial(PowerStrip, model=MODEL_POWER_STRIP_V1),
     "zimi-powerstrip-v2": partial(PowerStrip, model=MODEL_POWER_STRIP_V2),
     "zimi-clock-myk01": AlarmClock,
+    "xiaomi.aircondition.mc1": AirConditionerMiot,
+    "xiaomi.aircondition.mc2": AirConditionerMiot,
+    "xiaomi.aircondition.mc4": AirConditionerMiot,
+    "xiaomi.aircondition.mc5": AirConditionerMiot,
     "zhimi-airpurifier-m1": AirPurifier,  # mini model
     "zhimi-airpurifier-m2": AirPurifier,  # mini model 2
     "zhimi-airpurifier-ma1": AirPurifier,  # ms model
@@ -123,7 +134,10 @@ DEVICE_MAP = {
     "deerma-humidifier-mjjsq": partial(
         AirHumidifierMjjsq, model=MODEL_HUMIDIFIER_MJJSQ
     ),
+    "deerma-humidifier-jsq1": partial(AirHumidifierMjjsq, model=MODEL_HUMIDIFIER_JSQ1),
     "yunmi-waterpuri-v2": WaterPurifier,
+    "yunmi.waterpuri.lx9": WaterPurifierYunmi,
+    "yunmi.waterpuri.lx11": WaterPurifierYunmi,
     "philips-light-bulb": PhilipsBulb,  # cannot be discovered via mdns
     "philips-light-hbulb": PhilipsWhiteBulb,  # cannot be discovered via mdns
     "philips-light-candle": PhilipsBulb,  # cannot be discovered via mdns
@@ -146,6 +160,9 @@ DEVICE_MAP = {
     "lumi-acpartner-v1": partial(AirConditioningCompanion, model=MODEL_ACPARTNER_V1),
     "lumi-acpartner-v2": partial(AirConditioningCompanion, model=MODEL_ACPARTNER_V2),
     "lumi-acpartner-v3": partial(AirConditioningCompanion, model=MODEL_ACPARTNER_V3),
+    "lumi-acpartner-mcn02": partial(
+        AirConditioningCompanionMcn02, model=MODEL_ACPARTNER_MCN02
+    ),
     "lumi-camera-aq2": AqaraCamera,
     "yeelink-light-": Yeelight,
     "zhimi-fan-v2": partial(Fan, model=MODEL_FAN_V2),
@@ -155,8 +172,12 @@ DEVICE_MAP = {
     "zhimi-fan-za3": partial(Fan, model=MODEL_FAN_ZA3),
     "zhimi-fan-za4": partial(Fan, model=MODEL_FAN_ZA4),
     "dmaker-fan-p5": partial(Fan, model=MODEL_FAN_P5),
+    "dmaker-fan-p9": partial(FanMiot, model=MODEL_FAN_P9),
+    "dmaker-fan-p10": partial(FanMiot, model=MODEL_FAN_P10),
+    "dmaker-fan-p11": partial(FanMiot, model=MODEL_FAN_P11),
     "tinymu-toiletlid-v1": partial(Toiletlid, model=MODEL_TOILETLID_V1),
-    "zhimi-airfresh-va2": AirFresh,
+    "zhimi-airfresh-va2": partial(AirFresh, model=MODEL_AIRFRESH_VA2),
+    "zhimi-airfresh-va4": partial(AirFresh, model=MODEL_AIRFRESH_VA4),
     "dmaker-airfresh-t2017": AirFreshT2017,
     "zhimi-airmonitor-v1": partial(AirQualityMonitor, model=MODEL_AIRQUALITYMONITOR_V1),
     "cgllc-airmonitor-b1": partial(AirQualityMonitor, model=MODEL_AIRQUALITYMONITOR_B1),
@@ -207,7 +228,7 @@ class Listener:
 
     def check_and_create_device(self, info, addr) -> Optional[Device]:
         """Create a corresponding :class:`Device` implementation
-         for a given info and address.."""
+        for a given info and address.."""
         name = info.name
         for identifier, v in DEVICE_MAP.items():
             if name.startswith(identifier):
