@@ -1,4 +1,3 @@
-import enum
 import logging
 from typing import Any, Dict, Optional
 
@@ -6,7 +5,7 @@ import click
 
 from .click_common import EnumType, command, format_output
 from .device import Device
-from .exceptions import DeviceException
+from .fan_common import FanException, LedBrightness, MoveDirection, OperationMode
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -64,26 +63,6 @@ AVAILABLE_PROPERTIES = {
 }
 
 
-class FanException(DeviceException):
-    pass
-
-
-class OperationMode(enum.Enum):
-    Normal = "normal"
-    Nature = "nature"
-
-
-class LedBrightness(enum.Enum):
-    Bright = 0
-    Dim = 1
-    Off = 2
-
-
-class MoveDirection(enum.Enum):
-    Left = "left"
-    Right = "right"
-
-
 class FanStatus:
     """Container for status reports from the Xiaomi Mi Smart Pedestal Fan."""
 
@@ -272,9 +251,6 @@ class FanStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class FanStatusP5:
     """Container for status reports from the Xiaomi Mi Smart Pedestal Fan DMaker P5."""
@@ -363,9 +339,6 @@ class FanStatusP5:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class Fan(Device):
     """Main class representing the Xiaomi Mi Smart Pedestal Fan."""
@@ -455,7 +428,7 @@ class Fan(Device):
         return self.send("set_speed_level", [speed])
 
     @command(
-        click.argument("direction", type=EnumType(MoveDirection, False)),
+        click.argument("direction", type=EnumType(MoveDirection)),
         default_output=format_output("Rotating the fan to the {direction}"),
     )
     def set_rotate(self, direction: MoveDirection):
@@ -489,7 +462,7 @@ class Fan(Device):
             return self.send("set_angle_enable", ["off"])
 
     @command(
-        click.argument("brightness", type=EnumType(LedBrightness, False)),
+        click.argument("brightness", type=EnumType(LedBrightness)),
         default_output=format_output("Setting LED brightness to {brightness}"),
     )
     def set_led_brightness(self, brightness: LedBrightness):
@@ -663,7 +636,7 @@ class FanP5(Device):
         return self.send("s_power", [False])
 
     @command(
-        click.argument("mode", type=EnumType(OperationMode, False)),
+        click.argument("mode", type=EnumType(OperationMode)),
         default_output=format_output("Setting mode to '{mode.value}'"),
     )
     def set_mode(self, mode: OperationMode):
@@ -761,7 +734,7 @@ class FanP5(Device):
         return self.send("s_t_off", [minutes])
 
     @command(
-        click.argument("direction", type=EnumType(MoveDirection, False)),
+        click.argument("direction", type=EnumType(MoveDirection)),
         default_output=format_output("Rotating the fan to the {direction}"),
     )
     def set_rotate(self, direction: MoveDirection):
