@@ -105,9 +105,6 @@ class PhilipsMoonlightStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class PhilipsMoonlight(Device):
     """Main class representing Xiaomi Philips Zhirui Bedside Lamp.
