@@ -101,9 +101,6 @@ class PhilipsRwreadStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class PhilipsRwread(Device):
     """Main class representing Xiaomi Philips RW Read."""
@@ -202,7 +199,7 @@ class PhilipsRwread(Device):
         return self.send("enable_flm", [int(motion_detection)])
 
     @command(
-        click.argument("sensitivity", type=EnumType(MotionDetectionSensitivity, False)),
+        click.argument("sensitivity", type=EnumType(MotionDetectionSensitivity)),
         default_output=format_output(
             "Setting motion detection sensitivity to {sensitivity}"
         ),
