@@ -157,9 +157,6 @@ class PowerStripStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class PowerStrip(Device):
     """Main class representing the smart power strip."""
@@ -213,7 +210,7 @@ class PowerStrip(Device):
         return self.send("set_power", ["off"])
 
     @command(
-        click.argument("mode", type=EnumType(PowerMode, False)),
+        click.argument("mode", type=EnumType(PowerMode)),
         default_output=format_output("Setting mode to {mode}"),
     )
     def set_power_mode(self, mode: PowerMode):
