@@ -102,9 +102,6 @@ class PwznRelayStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class PwznRelay(Device):
     """Main class representing the PWZN Relay."""
