@@ -12,7 +12,13 @@ import click
 import pytz
 from appdirs import user_cache_dir
 
-from .click_common import DeviceGroup, GlobalContextObject, LiteralParamType, command
+from .click_common import (
+    DeviceGroup,
+    EnumType,
+    GlobalContextObject,
+    LiteralParamType,
+    command,
+)
 from .device import Device
 from .exceptions import DeviceException, DeviceInfoUnavailableException
 from .vacuumcontainers import (
@@ -70,7 +76,7 @@ class FanspeedE2(enum.Enum):
     Turbo = 100
 
 
-class WaterFlow:
+class WaterFlow(enum.Enum):
     """Water flow strength on s5 max. """
 
     Minimum = 200
@@ -162,12 +168,22 @@ class Vacuum(Device):
         self.manual_seqnum = 0
         return self.send("app_rc_end")
 
+    MANUAL_ROTATION_MAX = 180
+    MANUAL_ROTATION_MIN = -MANUAL_ROTATION_MAX
+    MANUAL_VELOCITY_MAX = 0.3
+    MANUAL_VELOCITY_MIN = -MANUAL_VELOCITY_MAX
+    MANUAL_DURATION_DEFAULT = 1500
+
     @command(
         click.argument("rotation", type=int),
         click.argument("velocity", type=float),
-        click.argument("duration", type=int, required=False, default=1500),
+        click.argument(
+            "duration", type=int, required=False, default=MANUAL_DURATION_DEFAULT
+        ),
     )
-    def manual_control_once(self, rotation: int, velocity: float, duration: int = 1500):
+    def manual_control_once(
+        self, rotation: int, velocity: float, duration: int = MANUAL_DURATION_DEFAULT
+    ):
         """Starts the remote control mode and executes
         the action once before deactivating the mode."""
         number_of_tries = 3
@@ -185,18 +201,23 @@ class Vacuum(Device):
     @command(
         click.argument("rotation", type=int),
         click.argument("velocity", type=float),
-        click.argument("duration", type=int, required=False, default=1500),
+        click.argument(
+            "duration", type=int, required=False, default=MANUAL_DURATION_DEFAULT
+        ),
     )
-    def manual_control(self, rotation: int, velocity: float, duration: int = 1500):
+    def manual_control(
+        self, rotation: int, velocity: float, duration: int = MANUAL_DURATION_DEFAULT
+    ):
         """Give a command over manual control interface."""
-        if rotation < -180 or rotation > 180:
+        if rotation < self.MANUAL_ROTATION_MIN or rotation > self.MANUAL_ROTATION_MAX:
             raise DeviceException(
-                "Given rotation is invalid, should " "be ]-180, 180[, was %s" % rotation
+                "Given rotation is invalid, should be ]%s, %s[, was %s"
+                % (self.MANUAL_ROTATION_MIN, self.MANUAL_ROTATION_MAX, rotation)
             )
-        if velocity < -0.3 or velocity > 0.3:
+        if velocity < self.MANUAL_VELOCITY_MIN or velocity > self.MANUAL_VELOCITY_MAX:
             raise DeviceException(
-                "Given velocity is invalid, should "
-                "be ]-0.3, 0.3[, was: %s" % velocity
+                "Given velocity is invalid, should be ]%s, %s[, was: %s"
+                % (self.MANUAL_VELOCITY_MIN, self.MANUAL_VELOCITY_MAX, velocity)
             )
 
         self.manual_seqnum += 1
@@ -374,9 +395,12 @@ class Vacuum(Device):
     def timer(self) -> List[Timer]:
         """Return a list of timers."""
         timers = list()
-        timezone = self.timezone()
+        timezone = pytz.timezone(self.timezone())
         for rec in self.send("get_timer", [""]):
-            timers.append(Timer(rec, timezone=timezone))
+            try:
+                timers.append(Timer(rec, timezone=timezone))
+            except Exception as ex:
+                _LOGGER.warning("Unable to add timer for %s: %s", rec, ex)
 
         return timers
 
@@ -649,10 +673,6 @@ class Vacuum(Device):
         """Get the status of a segment."""
         return self.send("get_segment_status")
 
-    @property
-    def raw_id(self):
-        return self._protocol.raw_id
-
     def name_segment(self):
         raise NotImplementedError("unknown parameters")
         # return self.send("name_segment")
@@ -670,7 +690,7 @@ class Vacuum(Device):
         """Get water flow setting."""
         return WaterFlow(self.send("get_water_box_custom_mode")[0])
 
-    @command(click.argument("waterflow", type=WaterFlow))
+    @command(click.argument("waterflow", type=EnumType(WaterFlow)))
     def set_waterflow(self, waterflow: WaterFlow):
         """Set water flow setting."""
         return self.send("set_water_box_custom_mode", [waterflow.value])
