@@ -231,6 +231,13 @@ def manual(vac: miio.Vacuum):
     # if not vac.manual_mode and command :
 
 
+@manual.command()
+@pass_dev
+def tui(vac: miio.Vacuum):
+    """TUI for the manual mode."""
+    miio.VacuumTUI(vac).run()
+
+
 @manual.command()
 @pass_dev
 def start(vac: miio.Vacuum):  # noqa: F811  # redef of start
@@ -587,7 +594,7 @@ def update_firmware(vac: miio.Vacuum, url: str, md5: str, ip: str):
 
     `--ip` can be used to override automatically detected IP address for
      the device to contact for the update.
-     """
+    """
 
     # TODO Check that the device is in updateable state.
 
