@@ -4,7 +4,6 @@ from enum import IntEnum
 from typing import Any, Dict, List
 
 from croniter import croniter
-from pytz import timezone
 
 from .utils import pretty_seconds, pretty_time
 
@@ -186,9 +185,6 @@ class VacuumStatus:
         s += "cleaned %s m² in %s>" % (self.clean_area, self.clean_time)
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class CleaningSummary:
     """Contains summarized information about available cleaning runs."""
@@ -228,9 +224,6 @@ class CleaningSummary:
             % (self.count, self.total_duration, self.total_area, self.ids)  # noqa: E501
         )
 
-    def __json__(self):
-        return self.data
-
 
 class CleaningDetails:
     """Contains details about a specific cleaning run."""
@@ -274,7 +267,7 @@ class CleaningDetails:
     def complete(self) -> bool:
         """Return True if the cleaning run was complete (e.g. without errors).
 
-         see also :func:`error`."""
+        see also :func:`error`."""
         return bool(self.data[5] == 1)
 
     def __repr__(self) -> str:
@@ -285,9 +278,6 @@ class CleaningDetails:
             self.area,
         )
 
-    def __json__(self):
-        return self.data
-
 
 class ConsumableStatus:
     """Container for consumable status information,
@@ -361,9 +351,6 @@ class ConsumableStatus:
             )
         )
 
-    def __json__(self):
-        return self.data
-
 
 class DNDStatus:
     """A container for the do-not-disturb status."""
@@ -395,16 +382,13 @@ class DNDStatus:
             self.end,
         )
 
-    def __json__(self):
-        return self.data
-
 
 class Timer:
     """A container for scheduling.
     The timers are accessed using an integer ID, which is based on the unix
     timestamp of the creation time."""
 
-    def __init__(self, data: List[Any], timezone: str) -> None:
+    def __init__(self, data: List[Any], timezone: "datetime.tzinfo") -> None:
         # id / timestamp, enabled, ['<cron string>', ['command', 'params']
         # [['1488667794112', 'off', ['49 22 * * 6', ['start_clean', '']]],
         #  ['1488667777661', 'off', ['49 21 * * 3,4,5,6', ['start_clean', '']]
@@ -412,6 +396,11 @@ class Timer:
         self.data = data
         self.timezone = timezone
 
+        # Initialize croniter to cause an exception on invalid entries (#847)
+        self.croniter = croniter(
+            self.cron, start_time=timezone.localize(datetime.now())
+        )
+
     @property
     def id(self) -> int:
         """ID which can be used to point to this timer."""
@@ -441,10 +430,7 @@ class Timer:
     @property
     def next_schedule(self) -> datetime:
         """Next schedule for the timer."""
-        local_tz = timezone(self.timezone)
-        cron = croniter(self.cron, start_time=local_tz.localize(datetime.now()))
-
-        return cron.get_next(ret_type=datetime)
+        return self.croniter.get_next(ret_type=datetime)
 
     def __repr__(self) -> str:
         return "<Timer %s: %s - enabled: %s - cron: %s>" % (
@@ -454,9 +440,6 @@ class Timer:
             self.cron,
         )
 
-    def __json__(self):
-        return self.data
-
 
 class SoundStatus:
     """Container for sound status."""
@@ -479,9 +462,6 @@ class SoundStatus:
             self.being_installed,
         )
 
-    def __json__(self):
-        return self.data
-
 
 class SoundInstallState(IntEnum):
     Unknown = 0
@@ -544,9 +524,6 @@ class SoundInstallStatus:
             " - progress: %s>" % (self.sid, self.state, self.error, self.progress)
         )
 
-    def __json__(self):
-        return self.data
-
 
 class CarpetModeStatus:
     """Container for carpet mode status."""
@@ -590,6 +567,3 @@ class CarpetModeStatus:
                 self.current_integral,
             )
         )
-
-    def __json__(self):
-        return self.data
