@@ -3,14 +3,14 @@ import time
 from collections import defaultdict
 from datetime import timedelta
 from enum import Enum
-from typing import Dict, Optional
+from typing import Dict, List, Optional
 
 import click
 
 from .click_common import EnumType, command, format_output
 from .device import Device
 from .utils import pretty_seconds
-from .vacuumcontainers import DNDStatus
+from .vacuumcontainers import ConsumableStatus, DNDStatus
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -38,9 +38,71 @@ ERROR_CODES = {
     530: "Mop and water tank missing",
     531: "Water tank is not installed",
     2101: "Unsufficient battery, continuing cleaning after recharge",
+    2103: "Charging",
+    2105: "Fully charged",
 }
 
 
+class ViomiConsumableStatus(ConsumableStatus):
+    def __init__(self, data: List[int]) -> None:
+        # [17, 17, 17, 17]
+        self.data = [d * 60 * 60 for d in data]
+        self.side_brush_total = timedelta(hours=180)
+        self.main_brush_total = timedelta(hours=360)
+        self.filter_total = timedelta(hours=180)
+        self.mop_total = timedelta(hours=180)
+
+    @property
+    def main_brush(self) -> timedelta:
+        """Main brush usage time."""
+        return pretty_seconds(self.data[0])
+
+    @property
+    def main_brush_left(self) -> timedelta:
+        """How long until the main brush should be changed."""
+        return self.main_brush_total - self.main_brush
+
+    @property
+    def side_brush(self) -> timedelta:
+        """Side brush usage time."""
+        return pretty_seconds(self.data[1])
+
+    @property
+    def side_brush_left(self) -> timedelta:
+        """How long until the side brush should be changed."""
+        return self.side_brush_total - self.side_brush
+
+    @property
+    def filter(self) -> timedelta:
+        """Filter usage time."""
+        return pretty_seconds(self.data[2])
+
+    @property
+    def filter_left(self) -> timedelta:
+        """How long until the filter should be changed."""
+        return self.filter_total - self.filter
+
+    @property
+    def mop(self) -> timedelta:
+        """Return ``sensor_dirty_time``"""
+        return pretty_seconds(self.data[3])
+
+    @property
+    def mop_left(self) -> timedelta:
+        return self.sensor_dirty_total - self.sensor_dirty
+
+    def __repr__(self) -> str:
+        return (
+            "<ConsumableStatus main: %s, side: %s, filter: %s, mop: %s>"
+            % (  # noqa: E501
+                self.main_brush,
+                self.side_brush,
+                self.filter,
+                self.mop,
+            )
+        )
+
+
 class ViomiVacuumSpeed(Enum):
     Silent = 0
     Standard = 1
@@ -49,18 +111,22 @@ class ViomiVacuumSpeed(Enum):
 
 
 class ViomiVacuumState(Enum):
+    Unknown = -1
     IdleNotDocked = 0
     Idle = 1
     Idle2 = 2
     Cleaning = 3
     Returning = 4
     Docked = 5
+    VacuumingAndMopping = 6
 
 
 class ViomiMode(Enum):
     Vacuum = 0  # No Mop, Vacuum only
     VacuumAndMop = 1
     Mop = 2
+    CleanZone = 3
+    CleanSpot = 4
 
 
 class ViomiLanguage(Enum):
@@ -92,6 +158,7 @@ class ViomiBinType(Enum):
     Vacuum = 1
     Water = 2
     VacuumAndWater = 3
+    NoBin = 0
 
 
 class ViomiWaterGrade(Enum):
@@ -118,12 +185,20 @@ class ViomiVacuumStatus:
     @property
     def state(self):
         """State of the vacuum."""
-        return ViomiVacuumState(self.data["run_state"])
+        try:
+            return ViomiVacuumState(self.data["run_state"])
+        except ValueError:
+            _LOGGER.warning("Unknown vacuum state: %s", self.data["run_state"])
+            return ViomiVacuumState.Unknown
 
     @property
     def is_on(self) -> bool:
         """True if cleaning."""
-        return self.state == ViomiVacuumState.Cleaning
+        cleaning_states = [
+            ViomiVacuumState.Cleaning,
+            ViomiVacuumState.VacuumingAndMopping,
+        ]
+        return self.state in cleaning_states
 
     @property
     def mode(self):
@@ -141,7 +216,6 @@ class ViomiVacuumStatus:
     @property
     def error_code(self) -> int:
         """Error code from vacuum."""
-
         return self.data["err_state"]
 
     @property
@@ -267,7 +341,7 @@ class ViomiVacuum(Device):
         """Pause cleaning."""
         self.send("set_mode_withroom", [0, 2, 0])
 
-    @command(click.argument("speed", type=EnumType(ViomiVacuumSpeed, False)))
+    @command(click.argument("speed", type=EnumType(ViomiVacuumSpeed)))
     def set_fan_speed(self, speed: ViomiVacuumSpeed):
         """Set fanspeed [silent, standard, medium, turbo]."""
         self.send("set_suction", [speed.value])
@@ -283,7 +357,7 @@ class ViomiVacuum(Device):
         self.send("set_charge", [1])
 
     @command(
-        click.argument("direction", type=EnumType(ViomiMovementDirection, False)),
+        click.argument("direction", type=EnumType(ViomiMovementDirection)),
         click.option(
             "--duration",
             type=float,
@@ -299,15 +373,20 @@ class ViomiVacuum(Device):
             time.sleep(0.1)
         self.send("set_direction", [ViomiMovementDirection.Stop.value])
 
-    @command(click.argument("mode", type=EnumType(ViomiMode, False)))
+    @command(click.argument("mode", type=EnumType(ViomiMode)))
     def clean_mode(self, mode):
         """Set the cleaning mode."""
         self.send("set_mop", [mode.value])
 
-    @command(click.argument("mop_mode", type=EnumType(ViomiMopMode, False)))
+    @command(click.argument("mop_mode", type=EnumType(ViomiMopMode)))
     def mop_mode(self, mop_mode):
         self.send("set_moproute", [mop_mode.value])
 
+    @command()
+    def consumable_status(self) -> ViomiConsumableStatus:
+        """Return information about consumables."""
+        return ViomiConsumableStatus(self.send("get_consumables"))
+
     @command()
     def dnd_status(self):
         """Returns do-not-disturb status."""
@@ -343,12 +422,12 @@ class ViomiVacuum(Device):
             [0 if disable else 1, start_hr, start_min, end_hr, end_min],
         )
 
-    @command(click.argument("language", type=EnumType(ViomiLanguage, False)))
+    @command(click.argument("language", type=EnumType(ViomiLanguage)))
     def set_language(self, language: ViomiLanguage):
         """Set the device's audio language."""
         return self.send("set_language", [language.value])
 
-    @command(click.argument("state", type=EnumType(ViomiLedState, False)))
+    @command(click.argument("state", type=EnumType(ViomiLedState)))
     def led(self, state: ViomiLedState):
         """Switch the button leds on or off."""
         return self.send("set_light", [state.value])
