@@ -46,9 +46,6 @@ class WifiRepeaterStatus:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class WifiRepeaterConfiguration:
     def __init__(self, data):
@@ -79,9 +76,6 @@ class WifiRepeaterConfiguration:
         )
         return s
 
-    def __json__(self):
-        return self.data
-
 
 class WifiRepeater(Device):
     """Device class for Xiaomi Mi WiFi Repeater 2."""
